import psycopg2
import psycopg2.extras

insert_citation_query = "INSERT INTO citation_entry (citationid, citingcorpusid, citedcorpusid, isinfluential) VALUES (%s, %s, %s, %s)"
insert_context_query = "INSERT INTO citation_context (citationid, context_text, intent_text) VALUES (%s, %s, %s)"

def convert_to_int(value):
    if value is None:
        return value
    elif isinstance(value, str):
        value = int(value)
    elif not isinstance(value, int):
        raise(ValueError("Value is not a string or integer"))
    return value

def process_base_info(json_obj):
    # Extract data from JSON object
    citationid = json_obj['citationid']
    citingcorpusid = json_obj['citingcorpusid']
    citedcorpusid = json_obj['citedcorpusid']
    isinfluential = json_obj['isinfluential']
    
    citationid = convert_to_int(citationid)
    citingcorpusid = convert_to_int(citingcorpusid)
    citedcorpusid = convert_to_int(citedcorpusid)

    return citationid, citingcorpusid, citedcorpusid, isinfluential

def process_context(json_obj):
    # contexts and intents go together
    citationid = json_obj['citationid']
    contexts = json_obj.get('contexts', [])  # Get contexts array, return empty list if not present
    intents = json_obj.get('intents')  # Get intents array, return empty list if not present
    if intents:
        if isinstance(intents, list):
            intents = intents
        elif not isinstance(intents, str):
            raise(ValueError("Intents is not a list or string"))
                
    if contexts and intents:
        if (len(contexts) != len(intents)):
            raise(ValueError("Contexts and intents are not the same length"))
        
        # Create an array of tuples with context and intent entries
        context_tuples = []
        for context, intent in zip(contexts, intents):
            if intent is not None:
                intent = intent[0]
            context_tuples.append((citationid, context, intent))
        return context_tuples


def process_line(line):
    base_tuple = process_base_info(line)
    context_tuples = process_context(line)

    return base_tuple, context_tuples

def batch_insert_citation(cursor, inputs):
    base_tuples = []
    context_tuples = []

    for tup in inputs:
        base_tuples.append(tup[0])
        if tup[1] is not None:
            context_tuples.extend(tup[1])

    psycopg2.extras.execute_batch(cursor, insert_citation_query, base_tuples)
    psycopg2.extras.execute_batch(cursor, insert_context_query, context_tuples)
