import requests
import json
import os

# Define the JSON data containing file URLs
json_data = '''
{
    "name": "s2orc",
    "description": "Full-body paper text parsed from open-access PDFs. Identifies structural elements such as paragraphs, sections, and bibliography entries.\n10M records in 30 4GB files.",
    "README": "Semantic Scholar Academic Graph Datasets\n\nThe \"s2orc\" dataset contains parsed full-body text from selected papers.\n\nA subset of this data was previously released (in a different format) as S2ORC",
    "files": ["file_url1", "file_url2", "file_url3"]
}
'''

with open('./s2orc.json', 'r') as file:
    data = json.load(file)

# Create a directory to store the downloaded files
if not os.path.exists(data["name"]):
    os.makedirs(data["name"])

# Iterate over file URLs and download each file
for file_url in data["files"]:
    # Use the URL's path as the filename, not the whole URL
    filename = os.path.basename(file_url.split("?")[0])
    filepath = os.path.join(data["name"], filename)

    print("Downloading:", filename)
    response = requests.get(file_url, stream=True)
    
    # Check if the request was successful
    if response.status_code == 200:
        # Save the file
        with open(filename, 'wb') as file:
            for chunk in response.iter_content(chunk_size=1024): 
                if chunk:
                    file.write(chunk)
        print("File downloaded successfully as:", filepath)
    else:
        print("Failed to download:", filename)


